# This package is for EPEL only
# Dependencies for check and wheel introduce circular dependencies
# Build '--with bootstrap' to disable them.
%bcond_with bootstrap

# Tests fail with some version of pytest 3:
# https://github.com/pytest-dev/pytest/issues/1888
%bcond_without tests

%global srcname setuptools
%if %{without bootstrap}
%global python3_wheelname %{srcname}-%{version}-py2.py3-none-any.whl
%global python3_record %{python3_sitelib}/%{srcname}-%{version}.dist-info/RECORD
%if 0%{?with_python3_other}
%global python3_other_record %{python3_other_sitelib}/%{srcname}-%{version}.dist-info/RECORD
%endif
%endif

Name:           python3-setuptools
Version:        36.5.0
Release:        1%{?dist}
Summary:        Easily build and distribute Python 3 packages

# Licensing is in flux, see https://bitbucket.org/pypa/setuptools/issues/132/missing-license
License:        MIT
URL:            https://pypi.python.org/pypi/%{srcname}
Source0:        https://files.pythonhosted.org/packages/source/s/%{srcname}/%{srcname}-%{version}.zip

# Use the versionned executables for pip in the tests.
Patch0:         setuptools-36.5.0-pipversion.patch

BuildArch:      noarch

BuildRequires:  python%{python3_pkgversion}-devel
%if %{with tests}
BuildRequires:  python%{python3_pkgversion}-pip
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-mock
%endif # with tests
%if %{without bootstrap}
BuildRequires:  python%{python3_pkgversion}-pip
BuildRequires:  python%{python3_pkgversion}-wheel
%endif # without bootstrap

%description
Setuptools is a collection of enhancements to the Python 3 distutils that allow
you to more easily build and distribute Python 3 packages, especially ones that
have dependencies on other packages.

This package also contains the runtime components of setuptools, necessary to
execute the software that requires pkg_resources.py.


%package -n python%{python3_pkgversion}-setuptools
Summary:        Easily build and distribute Python %{python3_pkgversion} packages
Group:          Applications/System
%{?python_provide:%python_provide python%{python3_pkgversion}-setuptools}

%description -n python%{python3_pkgversion}-setuptools
Setuptools is a collection of enhancements to the Python %{python3_pkgversion} distutils that allow
you to more easily build and distribute Python %{python3_pkgversion} packages, especially ones that
have dependencies on other packages.

This package also contains the runtime components of setuptools, necessary to
execute the software that requires pkg_resources.py.


%if 0%{?with_python3_other}
%package -n python%{python3_other_pkgversion}-setuptools
Summary:        Easily build and distribute Python %{python3_other_pkgversion} packages
Group:          Applications/System

%{?python_provide:%python_provide python%{python3_other_pkgversion}-setuptools}

BuildRequires:  python%{python3_other_pkgversion}-devel
%if %{with tests}
BuildRequires:  python%{python3_other_pkgversion}-pip
BuildRequires:  python%{python3_other_pkgversion}-pytest
BuildRequires:  python%{python3_other_pkgversion}-mock
%endif # with tests
%if %{without bootstrap}
BuildRequires:  python%{python3_other_pkgversion}-pip
BuildRequires:  python%{python3_other_pkgversion}-wheel
%endif # without bootstrap

%description -n python%{python3_other_pkgversion}-setuptools
Setuptools is a collection of enhancements to the Python %{python3_other_pkgversion} distutils that allow
you to more easily build and distribute Python %{python3_other_pkgversion} packages, especially ones that
have dependencies on other packages.

This package also contains the runtime components of setuptools, necessary to
execute the software that requires pkg_resources.py.
%endif


%prep
%autosetup -p0 -n %{srcname}-%{version}

# We can't remove .egg-info (but it doesn't matter, since it'll be rebuilt):
#  The problem is that to properly execute setuptools' setup.py,
#   it is needed for setuptools to be loaded as a Distribution
#   (with egg-info or .dist-info dir), it's not sufficient
#   to just have them on PYTHONPATH
#  Running "setup.py install" without having setuptools installed
#   as a distribution gives warnings such as
#    ... distutils/dist.py:267: UserWarning: Unknown distribution option: 'entry_points'
#   and doesn't create "easy_install" and .egg-info directory
# Note: this is only a problem if bootstrapping wheel or building on RHEL,
#  otherwise setuptools are installed as dependency into buildroot

# Strip shbang
find setuptools -name \*.py | xargs sed -i -e '1 {/^#!\//d}'
# Remove bundled exes
rm -f setuptools/*.exe
# These tests require internet connection
rm setuptools/tests/test_integration.py 


%build
%if %{without bootstrap}
%py3_build_wheel
%else
%py3_build
%if 0%{?with_python3_other}
%py3_other_build
%endif
%endif


%install
%if %{without bootstrap}
%py3_install_wheel %{python3_wheelname}

# Remove /usr/bin/easy_install from the record as later on we delete the file
sed -i '/\/usr\/bin\/easy_install,/d' %{buildroot}%{python3_record}
%else
%py3_install
%endif

# TODO: we have to remove this by hand now, but it'd be nice if we wouldn't have to
# (pip install wheel doesn't overwrite)
rm %{buildroot}%{_bindir}/easy_install

rm -rf %{buildroot}%{python3_sitelib}/setuptools/tests
%if %{without bootstrap}
sed -i '/^setuptools\/tests\//d' %{buildroot}%{python3_record}
%endif

find %{buildroot}%{python3_sitelib} -name '*.exe' | xargs rm -f

%if 0%{?with_python3_other}
%if %{without bootstrap}
%py3_other_install_wheel %{python3_wheelname}
#pip%{python3_other_version} install -I dist/%{python3_wheelname} --root %{buildroot} --strip-file-prefix %{buildroot}
# Remove /usr/bin/easy_install from the record as later on we delete the file
sed -i '/\/usr\/bin\/easy_install,/d' %{buildroot}%{python3_other_record}
%else
%py3_other_install
%endif
rm %{buildroot}%{_bindir}/easy_install
rm -rf %{buildroot}%{python3_other_sitelib}/setuptools/tests
%if %{without bootstrap}
sed -i '/^setuptools\/tests\//d' %{buildroot}%{python3_other_record}
%endif
find %{buildroot}%{python3_other_sitelib} -name '*.exe' | xargs rm -f
%endif

# Don't ship these
rm -r docs/{Makefile,conf.py,_*}


%if %{with tests}
%check
LANG=en_US.utf8 PYTHONPATH=$(pwd) py.test-%{python3_version} --ignore setuptools/tests/test_virtualenv.py
%if 0%{?with_python3_other}
LANG=en_US.utf8 PYTHONPATH=$(pwd) py.test-%{python3_other_version} --ignore setuptools/tests/test_virtualenv.py
%endif
%endif


%files -n python%{python3_pkgversion}-setuptools
%license LICENSE
%doc docs/* CHANGES.rst README.rst
%{python3_sitelib}/easy_install.py
%{python3_sitelib}/pkg_resources/
%{python3_sitelib}/setuptools*/
%{python3_sitelib}/__pycache__/*
%{_bindir}/easy_install-%{python3_version}

%if 0%{?with_python3_other}
%files -n python%{python3_other_pkgversion}-setuptools
%license LICENSE
%doc docs/* CHANGES.rst README.rst
%{python3_other_sitelib}/easy_install.py
%{python3_other_sitelib}/pkg_resources/
%{python3_other_sitelib}/setuptools*/
%{python3_other_sitelib}/__pycache__/*
%{_bindir}/easy_install-%{python3_other_version}
%endif


%changelog
* Thu Oct 05 2017 Aurelien Bompard <abompard@fedoraproject.org> - 36.5.0-1
- Build for python3_other
- Upgrade to 36.5.0 for Python 3.6 compatibility

* Sun Oct 09 2016 Tim Orling <ticotimo@gmail.com> - 19.6.2-2
- Fixes for EPEL6 build

* Wed Feb 3 2016 Orion Poplawski <orion@cora.nwra.com> - 19.6.2-1
- Update to 19.6.2
- Update license
- Fix python3 package file ownership

* Wed Dec 30 2015 Orion Poplawski <orion@cora.nwra.com> - 19.2-3
- Cleanup docs
- Add version info to summary and description

* Wed Dec 30 2015 Orion Poplawski <orion@cora.nwra.com> - 19.2-2
- Drop group tag
- Add bootstrap conditional
- Use specific pip version
- Use %%license
- Update license and license source
- Strip unneeded shbangs

* Tue Dec 29 2015 Orion Poplawski <orion@cora.nwra.com> - 19.2-1
- Update to 19.2

* Tue Dec 29 2015 Orion Poplawski <orion@cora.nwra.com> - 19.1.1-1
- Initial EPEL package
